import java.io.*;
import java.util.*;

public class TreeInventory
{
  private LinkedList inventory;

   /**
   *  The constructor. It creates an inventory of Trees
   *  from a file. You do not need to be concerned with
   *  its implementation.
   *  @String fileName: the name of the data file containing the
   *  description of the Trees in the InventoryOfTrees.
   */
  public TreeInventory(String fileName)
  {
    String treeDescription;
    StringTokenizer treeDescriptionTokenizer;

    int heightInFeet;
    double priceInDollarsAndCents;
    int qualityFrom1Through10;

    // Create the LinkedList to hold the inventory of Trees
    inventory = new LinkedList();

    try {

      // Open the file and prepare for reading
      File dataFile = new File (fileName);
      BufferedReader fileData = new
        BufferedReader(new InputStreamReader (new FileInputStream(dataFile)));

      // Read each entry, creating a new tree.
      // Stops when it can't get a description line
      while (null != (treeDescription = fileData.readLine()))
      {
        // Break it into the individual descriptors
        treeDescriptionTokenizer = new StringTokenizer (treeDescription);
        heightInFeet =
          Integer.parseInt(treeDescriptionTokenizer.nextToken());
        priceInDollarsAndCents =
          Double.parseDouble(treeDescriptionTokenizer.nextToken());
        qualityFrom1Through10 =
          Integer.parseInt(treeDescriptionTokenizer.nextToken());

        // Create the new tree and add it to the inventory of trees
        inventory.addFirst (new Tree (heightInFeet, priceInDollarsAndCents,
                                      qualityFrom1Through10));
      }
    }
    catch (EOFException eof)
    {
      // Don't worry -- we're done
    }
    catch (Exception e)
    {
      // This is a real problem
      System.out.println ("Problem reading input file: " +
                           e.toString());
      System.exit (1);
    }
  }


  /**
    * This is the test program. It takes two parameters:
    * the names of two sorted lists of Trees
    * It will create a two TreeInventorys from the supplied
    * inventory files and then merge the two into one
    * LinkedList based inventory, which remains sorted.
    *
    * For example: java TreeInventory datafiles/lot2.dat datafiles/lot3.dat
    *
    * @args[0] is the name of one inventory file, including a path,
    * if necessary
    * @args[1] is the name of the other inventory file, including a path,
    * if necessary
    */
  public static void main (String[] args)
  {
    TreeInventory ti1 = new TreeInventory (args[0]);
    TreeInventory ti2 = new TreeInventory (args[1]);

    System.out.println ("The following is the initial list of Trees in " +
                         args[0]);
    System.out.println ("");
    System.out.println (ti1.inventory);
    System.out.println ("");

    System.out.println ("The following is the initial list of Trees in " +
                         args[1]);
    System.out.println ("");
    System.out.println (ti2.inventory);
    System.out.println ("");

    ti1.inventory.removeItems(ti2.inventory);

    System.out.println ("The following is the contents of " +
                         "the first list after the removal.");
    System.out.println ("");
    System.out.println (ti1.inventory);
    System.out.println ("");

    System.out.println ("The following is the contents of " +
                         "the second list after the removal.");
    System.out.println ("");
    System.out.println (ti2.inventory);
    System.out.println ("");




  }
}
